

set term ^ ;
ALTER PROCEDURE SET_PARAM(
  VAR_CLIENT_IP VARCHAR(15) CHARACTER SET WIN1250,
  VAR_USER VARCHAR(40) CHARACTER SET WIN1250,
  VAR_PARAM_NAME VARCHAR(40) CHARACTER SET WIN1250,
  VAR_PARAM_CAPTION VARCHAR(40) CHARACTER SET WIN1250,
  VAR_PARAM_DESCRIPTION VARCHAR(512) CHARACTER SET WIN1250,
  VAR_LANG_ID BIGINT,
  VAR_PARAM_NUM_VALUE BIGINT,
  VAR_PARAM_STR_VALUE VARCHAR(150) CHARACTER SET WIN1250)
RETURNS(
  RESULT SMALLINT)
AS
DECLARE VARIABLE TMP_DESC_ID BIGINT;
DECLARE VARIABLE TMP_OLD_NUM_VALUE BIGINT;
DECLARE VARIABLE TMP_OLD_STR_VALUE VARCHAR(150);
BEGIN

if ( VAR_PARAM_NAME is null or VAR_CLIENT_IP is null or VAR_USER is null
     or ( VAR_LANG_ID is null and VAR_PARAM_CAPTION is not null )
     or ( VAR_LANG_ID is null and VAR_PARAM_DESCRIPTION is not null )
     or ( VAR_PARAM_CAPTION is null and VAR_PARAM_DESCRIPTION is null and
     VAR_LANG_ID is null and VAR_PARAM_NUM_VALUE is null and
     VAR_PARAM_STR_VALUE is null )
   ) then
begin
     RESULT = -1;
     suspend;
     exit;
end

VAR_PARAM_NAME = upper(VAR_PARAM_NAME);
if (exists(
    select CONFIGURATION.ATTR_NUMERIC_VALUE
    from CONFIGURATION
    where CONFIGURATION.CLIENT_IP = :VAR_CLIENT_IP and
          CONFIGURATION.ATTR_NAME = :VAR_PARAM_NAME)) then
begin
     select max(configuration.ATTR_NUMERIC_VALUE),
            max(configuration.ATTR_STRING_VALUE)
     from configuration
     where configuration.CLIENT_IP = :VAR_CLIENT_IP and
           configuration.attr_name = :VAR_PARAM_NAME
     into :TMP_OLD_NUM_VALUE,
          :TMP_OLD_STR_VALUE;

     if ( VAR_PARAM_NUM_VALUE is not null and(TMP_OLD_NUM_VALUE <> VAR_PARAM_NUM_VALUE or TMP_OLD_NUM_VALUE is null) ) then -- save  the num value if it was given
     begin
            update CONFIGURATION
            set CONFIGURATION.ATTR_NUMERIC_VALUE = :VAR_PARAM_NUM_VALUE,
                CONFIGURATION.ATTR_MODIFIED = current_timestamp
            where CONFIGURATION.CLIENT_IP = :VAR_CLIENT_IP and
                  CONFIGURATION.ATTR_NAME = :VAR_PARAM_NAME;
            if ( VAR_USER <> 'NOCHANGELOG' and VAR_USER <> 'NO_CHANGE_LOG' and (TMP_OLD_NUM_VALUE is null or TMP_OLD_NUM_VALUE <> VAR_PARAM_NUM_VALUE) ) then
                 execute procedure WRITE_LOG(:VAR_CLIENT_IP, 0, 100601, '' || :VAR_USER || ' changed ' || :VAR_PARAM_NAME || ' from ' || coalesce(:TMP_OLD_NUM_VALUE, 'NULL') || ' to ' || :VAR_PARAM_NUM_VALUE);
     end
     if ( VAR_PARAM_STR_VALUE is not null and (TMP_OLD_STR_VALUE <> VAR_PARAM_STR_VALUE or TMP_OLD_STR_VALUE is null) ) then -- save the str value if it was given
     begin
            update CONFIGURATION
            set CONFIGURATION.ATTR_STRING_VALUE = :VAR_PARAM_STR_VALUE,
                CONFIGURATION.ATTR_MODIFIED = current_timestamp
            where CONFIGURATION.CLIENT_IP = :VAR_CLIENT_IP and
                  CONFIGURATION.ATTR_NAME = :VAR_PARAM_NAME;
            if ( VAR_USER  <> 'NOCHANGELOG' and VAR_USER <> 'NO_CHANGE_LOG' and (TMP_OLD_STR_VALUE is null or TMP_OLD_STR_VALUE <> VAR_PARAM_STR_VALUE) ) then
                 execute procedure WRITE_LOG(:VAR_CLIENT_IP, 0, 100601, '' || :VAR_USER || ' changed ' || :VAR_PARAM_NAME || ' from "' || substring(coalesce(:TMP_OLD_STR_VALUE, 'NULL') from 1 for 34) || '" to "'|| substring(:VAR_PARAM_STR_VALUE from 1 for 34)|| '"');
     end
     if ( VAR_PARAM_CAPTION is not null ) then --save the parameter caption in the given language
     begin
            SELECT max(CONFIGURATION.DESCRIPTION_ID)
            from CONFIGURATION
            where CONFIGURATION.CLIENT_IP = :VAR_CLIENT_IP and
                  CONFIGURATION.ATTR_NAME = :VAR_PARAM_NAME
            into :TMP_DESC_ID;
            if (exists(
                       select DESCRIPTIONS.DESC_ID
                       from DESCRIPTIONS
                       where DESCRIPTIONS.LANG_ID = :VAR_LANG_ID and
                             DESCRIPTIONS.DESC_ID = :TMP_DESC_ID)
               ) then
                 update DESCRIPTIONS
                 set DESCRIPTIONS.CAPTION = :VAR_PARAM_CAPTION
                 where DESCRIPTIONS.DESC_ID = :TMP_DESC_ID and
                       DESCRIPTIONS.LANG_ID = :VAR_LANG_ID;
            else
            begin
                if ( TMP_DESC_ID is null or -1 = TMP_DESC_ID ) then
                begin
                     TMP_DESC_ID = gen_id(GEN_DESCRIPTIONS,1);

                     update CONFIGURATION
                     set CONFIGURATION.DESCRIPTION_ID = :TMP_DESC_ID
                     where CONFIGURATION.CLIENT_IP = :VAR_CLIENT_IP and
                           CONFIGURATION.ATTR_NAME = :VAR_PARAM_NAME;
                end
                insert
                into DESCRIPTIONS(DESCRIPTIONS.DESC_ID, DESCRIPTIONS.LANG_ID,
                DESCRIPTIONS.CAPTION)
                values (:TMP_DESC_ID, :VAR_LANG_ID, :VAR_PARAM_CAPTION);
            end
     end

     if ( VAR_PARAM_DESCRIPTION is not null ) then -- save the parameter description in the given language
     begin
            SELECT max(CONFIGURATION.DESCRIPTION_ID)
            from CONFIGURATION
            where CONFIGURATION.CLIENT_IP = :VAR_CLIENT_IP and
                  CONFIGURATION.ATTR_NAME = :VAR_PARAM_NAME
            into :TMP_DESC_ID;
            if (exists(
                       select DESCRIPTIONS.DESC_ID
                       from DESCRIPTIONS
                       where DESCRIPTIONS.LANG_ID = :VAR_LANG_ID and
                             DESCRIPTIONS.DESC_ID = :TMP_DESC_ID)
               ) then
                 update DESCRIPTIONS
                 set DESCRIPTIONS.DESCRIPTION = :VAR_PARAM_DESCRIPTION
                 where DESCRIPTIONS.DESC_ID = :TMP_DESC_ID and
                       DESCRIPTIONS.LANG_ID = :VAR_LANG_ID;
            else
            begin
                if ( TMP_DESC_ID is null or -1 = TMP_DESC_ID ) then
                begin
                     TMP_DESC_ID = gen_id(GEN_DESCRIPTIONS,1);

                     update CONFIGURATION
                     set CONFIGURATION.DESCRIPTION_ID = :TMP_DESC_ID
                     where CONFIGURATION.CLIENT_IP = :VAR_CLIENT_IP and
                           CONFIGURATION.ATTR_NAME = :VAR_PARAM_NAME;
                end
                insert
                into DESCRIPTIONS(DESCRIPTIONS.DESC_ID, DESCRIPTIONS.LANG_ID,
                DESCRIPTIONS.DESCRIPTION)
                values (:TMP_DESC_ID, :VAR_LANG_ID, :VAR_PARAM_DESCRIPTION);
            end
     end

     -- we correct the user that has last modified the parameter value
     update CONFIGURATION
     set CONFIGURATION.USER_MODIFIED = :VAR_USER
     where CONFIGURATION.CLIENT_IP = :VAR_CLIENT_IP and
           CONFIGURATION.ATTR_NAME = :VAR_PARAM_NAME;

     RESULT = 0;
end
else
begin -- the parameter does not exist, so create one
       TMP_DESC_ID = -1;
       if ( VAR_PARAM_CAPTION is not null or VAR_PARAM_DESCRIPTION is not null
       ) then
       begin
                TMP_DESC_ID = gen_id(GEN_DESCRIPTIONS,1);
                insert into DESCRIPTIONS(DESCRIPTIONS.DESC_ID, DESCRIPTIONS.LANG_ID,
                DESCRIPTIONS.CAPTION, DESCRIPTIONS.DESCRIPTION)
                values (:TMP_DESC_ID, :VAR_LANG_ID, :VAR_PARAM_CAPTION,
                :VAR_PARAM_DESCRIPTION);
       end

       insert
       into CONFIGURATION(
                          CONFIGURATION.CLIENT_IP,
                          CONFIGURATION.USER_MODIFIED,
                          CONFIGURATION.ATTR_NAME,
                          CONFIGURATION.ATTR_NUMERIC_VALUE,
                          CONFIGURATION.ATTR_STRING_VALUE,
                          CONFIGURATION.DESCRIPTION_ID,
                          CONFIGURATION.ATTR_CREATED
                          )
                   values (
                          :VAR_CLIENT_IP,
                          :VAR_USER,
                          :VAR_PARAM_NAME,
                          :VAR_PARAM_NUM_VALUE,
                          :VAR_PARAM_STR_VALUE,
                          :TMP_DESC_ID,
                          current_timestamp
                          );
       if ( VAR_USER <> 'NOCHANGELOG' and VAR_USER <> 'NO_CHANGE_LOG' ) then
       begin
              if ( (VAR_PARAM_NUM_VALUE is not null) and (VAR_PARAM_STR_VALUE is not null) ) then
              begin
                  execute procedure WRITE_LOG(:VAR_CLIENT_IP, 0, 100602, '' || :VAR_USER || ' added ' || :VAR_PARAM_NAME || '=' || :VAR_PARAM_NUM_VALUE || ', "'|| substring(:VAR_PARAM_STR_VALUE from 1 for 60)|| '"');
              end
              else
                  if ( VAR_PARAM_STR_VALUE is null ) then
                     execute procedure WRITE_LOG(:VAR_CLIENT_IP, 0, 100602, '' || :VAR_USER || ' added ' || :VAR_PARAM_NAME || '=' || :VAR_PARAM_NUM_VALUE);
                  else
                     begin
                         execute procedure WRITE_LOG(:VAR_CLIENT_IP, 0, 100602, '' || :VAR_USER || ' added ' || :VAR_PARAM_NAME || '="'|| substring(:VAR_PARAM_STR_VALUE from 1 for 82)|| '"');
                     end
       end

       RESULT = 1;
  end



  SUSPEND;
END;
^

ALTER PROCEDURE LOG_TOTALS_ALL(
  VAR_COUNTER_ID_SHIFT BIGINT)
RETURNS(
  RES_CLIENT_IP VARCHAR(15),
  RES_CLIENT_CAPTION VARCHAR(40),
  RES_TOTAL_IN NUMERIC(18, 2),
  RES_TOTAL_OUT NUMERIC(18, 2),
  RES_TOTAL_BETS NUMERIC(18, 2),
  RES_TOTAL_WINS NUMERIC(18, 2),
  RES_BILL_IN NUMERIC(18, 2),
  RES_BILL_OUT NUMERIC(18, 2),
  RES_STACKER_TOTAL NUMERIC(18, 2),
  RES_BILLS_IN_STACKER BIGINT,
  RES_COIN_IN NUMERIC(18, 2),
  RES_COIN_OUT NUMERIC(18, 2),
  RES_COINS_TO_CASHBOX BIGINT,
  RES_COINS_TO_HOPPER BIGINT,
  RES_COIN_HOPPER_LEVEL BIGINT,
  RES_TOTAL_RES_BETS NUMERIC(18, 2),
  RES_TOTAL_NONRES_BETS NUMERIC(18, 2),
  RES_ELECTRONIC_IN NUMERIC(18, 2),
  RES_ELECTRONIC_OUT NUMERIC(18, 2),
  RES_ELECTRONIC_CASH_IN_CENTS NUMERIC(18, 2),
  RES_ELECTRONIC_CASH_OUT_CENTS NUMERIC(18, 2),
  RES_ELECTRONIC_RES_IN_CENTS NUMERIC(18, 2),
  RES_ELECTRONIC_RES_OUT_CENTS NUMERIC(18, 2),
  RES_ELECTRONIC_NONRES_IN_CENTS NUMERIC(18, 2),
  RES_ELECTRONIC_NONRES_OUT_CENTS NUMERIC(18, 2),
  RES_HANDPAY NUMERIC(18, 2),
  RES_ADMIN_KEY_IN NUMERIC(18, 2),
  RES_ADMIN_KEY_OUT NUMERIC(18, 2),
  RES_BONUS_CASH_IN_CENTS NUMERIC(18, 2),
  RES_BONUS_NONRES_IN_CENTS NUMERIC(18, 2),
  RES_BONUS_OUT NUMERIC(18, 2),
  RES_TICKETS_IN_QTY BIGINT,
  RES_TICKETS_OUT_QTY BIGINT,
  RES_TICKET_IN NUMERIC(18, 2),
  RES_TICKET_OUT NUMERIC(18, 2),
  RES_TICKET_CASH_IN NUMERIC(18, 2),
  RES_TICKET_CASH_OUT NUMERIC(18, 2),
  RES_TICKET_RES_IN NUMERIC(18, 2),
  RES_TICKET_RES_OUT NUMERIC(18, 2),
  RES_TICKET_NONRES_IN NUMERIC(18, 2),
  RES_JACKPOT_WIN NUMERIC(18, 2),
  RES_JACKPOTS_WON BIGINT,
  RES_BET_PROFIT_PERCENT VARCHAR(15),
  RES_PAYIN_PROFIT_PERCENT VARCHAR(15),
  RES_PAYBACK_PERCENT VARCHAR(15),
  RES_GAMES_PLAYED BIGINT,
  RES_GAMES_WON BIGINT,
  RES_GAMES_LOST BIGINT,
  RES_GAMES_SINCE_POWER_UP BIGINT,
  RES_GAMES_SINCE_DOOR_CLOSE BIGINT,
  RES_POWER_UP_COUNT BIGINT,
  RES_DOOR_CLOSE_COUNT BIGINT,
  RES_CREDITOS_TOTAL NUMERIC(18, 2),
  RES_RESERVA_TOTAL NUMERIC(18, 2),
  RES_BANCO_TOTAL NUMERIC(18, 2),
  RES_FICHAS_TOTAL NUMERIC(18, 2),
  RES_RESERVA_TO_CREDITOS NUMERIC(18, 2),
  RES_BANCO_TO_CREDITOS NUMERIC(18, 2),
  RES_FICHAS_TO_BANCO NUMERIC(18, 2),
  RES_RETURN_CHANGE_TOTAL NUMERIC(18, 2),
  RES_PAYOUT_ROUNDED_TOTAL NUMERIC(18, 2),
  RES_CYCLES_COMPLETED BIGINT,
  RES_FG_TOTAL_BET NUMERIC(18, 2),
  RES_FG_FICHAS_WIN NUMERIC(18, 2),
  RES_FG_PREMIO_WIN NUMERIC(18, 2),
  RES_FG_NADA_WIN NUMERIC(18, 2),
  RES_FG_RES_FICHAS_COUNT BIGINT,
  RES_FG_RES_PREMIO_COUNT BIGINT,
  RES_FG_RES_NADA_COUNT BIGINT,
  RES_FG_RES_MYSTERY_COUNT BIGINT,
  RES_FG_TOTAL_GAMES BIGINT,
  RES_FG_20_GAMES BIGINT,
  RES_FG_40_GAMES BIGINT,
  RES_FG_50_GAMES BIGINT,
  RES_FG_60_GAMES BIGINT,
  RES_FG_80_GAMES BIGINT,
  RES_FG_100_GAMES BIGINT,
  RES_FG_200_GAMES BIGINT,
  RES_FG_300_GAMES BIGINT,
  RES_FG_600_GAMES BIGINT,
  RES_NONRESTRICTED_BALANCE NUMERIC(18, 2),
  RES_CASHABLE_BALANCE NUMERIC(18, 2),
  RES_RESTRICTED_BALANCE NUMERIC(18, 2),
  RES_FICHAS_BALANCE NUMERIC(18, 2),
  RES_RESERVA_BALANCE NUMERIC(18, 2),
  RES_BANCO_BALANCE NUMERIC(18, 2),
  RES_COUNTING_FROM TIMESTAMP)
AS
DECLARE VARIABLE C_COEFF INTEGER;
DECLARE VARIABLE M_COEFF INTEGER;
DECLARE VARIABLE TMP_NONRESTRICTED_BALANCE NUMERIC(18, 2);
DECLARE VARIABLE TMP_CASHABLE_BALANCE NUMERIC(18, 2);
DECLARE VARIABLE TMP_RESTRICTED_BALANCE NUMERIC(18, 2);
DECLARE VARIABLE TMP_FICHAS_BALANCE NUMERIC(18, 2);
DECLARE VARIABLE TMP_RESERVA_BALANCE NUMERIC(18, 2);
DECLARE VARIABLE TMP_BANCO_BALANCE NUMERIC(18, 2);
DECLARE VARIABLE TMP_TOTAL_IN NUMERIC(18, 2);
DECLARE VARIABLE TMP_TOTAL_OUT NUMERIC(18, 2);
DECLARE VARIABLE TMP_TOTAL_BETS NUMERIC(18, 2);
DECLARE VARIABLE TMP_TOTAL_WINS NUMERIC(18, 2);
DECLARE VARIABLE TMP_TOTAL_RES_BETS NUMERIC(18, 2);
DECLARE VARIABLE TMP_TOTAL_NONRES_BETS NUMERIC(18, 2);
DECLARE VARIABLE TMP_BILL_IN NUMERIC(18, 2);
DECLARE VARIABLE TMP_BILL_OUT NUMERIC(18, 2);
DECLARE VARIABLE TMP_STACKER_TOTAL NUMERIC(18, 2);
DECLARE VARIABLE TMP_BILLS_IN_STACKER BIGINT;
DECLARE VARIABLE TMP_COIN_IN NUMERIC(18, 2);
DECLARE VARIABLE TMP_COIN_OUT NUMERIC(18, 2);
DECLARE VARIABLE TMP_COINS_TO_CASHBOX BIGINT;
DECLARE VARIABLE TMP_COINS_TO_HOPPER BIGINT;
DECLARE VARIABLE TMP_COIN_HOPPER_LEVEL BIGINT;
DECLARE VARIABLE TMP_ELECTRONIC_IN NUMERIC(18, 2);
DECLARE VARIABLE TMP_ELECTRONIC_OUT NUMERIC(18, 2);
DECLARE VARIABLE TMP_ELECTRONIC_CASH_IN_CENTS NUMERIC(18, 2);
DECLARE VARIABLE TMP_ELECTRONIC_CASH_OUT_CENTS NUMERIC(18, 2);
DECLARE VARIABLE TMP_ELECTRONIC_RES_IN_CENTS NUMERIC(18, 2);
DECLARE VARIABLE TMP_ELECTRONIC_RES_OUT_CENTS NUMERIC(18, 2);
DECLARE VARIABLE TMP_ELECTRONIC_NONRES_IN_CENTS NUMERIC(18, 2);
DECLARE VARIABLE TMP_ELECTRONIC_NONRES_OUT_CENTS NUMERIC(18, 2);
DECLARE VARIABLE TMP_HANDPAY NUMERIC(18, 2);
DECLARE VARIABLE TMP_ADMIN_KEY_IN NUMERIC(18, 2);
DECLARE VARIABLE TMP_ADMIN_KEY_OUT NUMERIC(18, 2);
DECLARE VARIABLE TMP_BONUS_CASH_IN_CENTS NUMERIC(18, 2);
DECLARE VARIABLE TMP_BONUS_NONRES_IN_CENTS NUMERIC(18, 2);
DECLARE VARIABLE TMP_BONUS_OUT NUMERIC(18, 2);
DECLARE VARIABLE TMP_TICKETS_IN_QTY NUMERIC(18, 2);
DECLARE VARIABLE TMP_TICKETS_OUT_QTY NUMERIC(18, 2);
DECLARE VARIABLE TMP_TICKET_IN NUMERIC(18, 2);
DECLARE VARIABLE TMP_TICKET_OUT NUMERIC(18, 2);
DECLARE VARIABLE TMP_TICKET_CASH_IN NUMERIC(18, 2);
DECLARE VARIABLE TMP_TICKET_CASH_OUT NUMERIC(18, 2);
DECLARE VARIABLE TMP_TICKET_RES_IN NUMERIC(18, 2);
DECLARE VARIABLE TMP_TICKET_RES_OUT NUMERIC(18, 2);
DECLARE VARIABLE TMP_TICKET_NONRES_IN NUMERIC(18, 2);
DECLARE VARIABLE TMP_JACKPOT_WIN NUMERIC(18, 2);
DECLARE VARIABLE TMP_JACKPOTS_WON NUMERIC(18, 2);
DECLARE VARIABLE TMP_GAMES_PLAYED BIGINT;
DECLARE VARIABLE TMP_GAMES_WON BIGINT;
DECLARE VARIABLE TMP_GAMES_LOST BIGINT;
DECLARE VARIABLE TMP_GAMES_SINCE_POWER_UP BIGINT;
DECLARE VARIABLE TMP_GAMES_SINCE_DOOR_CLOSE BIGINT;
DECLARE VARIABLE TMP_POWER_UP_COUNT BIGINT;
DECLARE VARIABLE TMP_DOOR_CLOSE_COUNT BIGINT;
DECLARE VARIABLE TMP_TICKET_RESTRICTED_IN NUMERIC(18, 2);
DECLARE VARIABLE TMP_TICKET_RESTRICTED_OUT NUMERIC(18, 2);
DECLARE VARIABLE TMP_ELECT_CASH_IN_CENTS NUMERIC(18, 2);
DECLARE VARIABLE TMP_ELECT_CASH_OUT_CENTS NUMERIC(18, 2);
DECLARE VARIABLE TMP_ELECT_RES_IN_CENTS NUMERIC(18, 2);
DECLARE VARIABLE TMP_ELECT_RES_OUT_CENTS NUMERIC(18, 2);
DECLARE VARIABLE TMP_ELECT_NONRES_IN_CENTS NUMERIC(18, 2);
DECLARE VARIABLE TMP_ELECT_NONRES_OUT_CENTS NUMERIC(18, 2);
DECLARE VARIABLE TMP_CREDITOS_TOTAL NUMERIC(18, 2);
DECLARE VARIABLE TMP_RESERVA_TOTAL NUMERIC(18, 2);
DECLARE VARIABLE TMP_BANCO_TOTAL NUMERIC(18, 2);
DECLARE VARIABLE TMP_FICHAS_TOTAL NUMERIC(18, 2);
DECLARE VARIABLE TMP_RESERVA_TO_CREDITOS NUMERIC(18, 2);
DECLARE VARIABLE TMP_BANCO_TO_CREDITOS NUMERIC(18, 2);
DECLARE VARIABLE TMP_FICHAS_TO_BANCO NUMERIC(18, 2);
DECLARE VARIABLE TMP_RETURN_CHANGE_TOTAL NUMERIC(18, 2);
DECLARE VARIABLE TMP_PAYOUT_ROUNDED_TOTAL NUMERIC(18, 2);
DECLARE VARIABLE TMP_CYCLES_COMPLETED BIGINT;
DECLARE VARIABLE TMP_FG_TOTAL_BET NUMERIC(18, 2);
DECLARE VARIABLE TMP_FG_FICHAS_WIN NUMERIC(18, 2);
DECLARE VARIABLE TMP_FG_PREMIO_WIN NUMERIC(18, 2);
DECLARE VARIABLE TMP_FG_NADA_WIN NUMERIC(18, 2);
DECLARE VARIABLE TMP_FG_RES_FICHAS_COUNT BIGINT;
DECLARE VARIABLE TMP_FG_RES_PREMIO_COUNT BIGINT;
DECLARE VARIABLE TMP_FG_RES_NADA_COUNT BIGINT;
DECLARE VARIABLE TMP_FG_RES_MYSTERY_COUNT BIGINT;
DECLARE VARIABLE TMP_FG_TOTAL_GAMES BIGINT;
DECLARE VARIABLE TMP_FG_20_GAMES BIGINT;
DECLARE VARIABLE TMP_FG_40_GAMES BIGINT;
DECLARE VARIABLE TMP_FG_50_GAMES BIGINT;
DECLARE VARIABLE TMP_FG_60_GAMES BIGINT;
DECLARE VARIABLE TMP_FG_80_GAMES BIGINT;
DECLARE VARIABLE TMP_FG_100_GAMES BIGINT;
DECLARE VARIABLE TMP_FG_200_GAMES BIGINT;
DECLARE VARIABLE TMP_FG_300_GAMES BIGINT;
DECLARE VARIABLE TMP_FG_600_GAMES BIGINT;
DECLARE VARIABLE TMP_MIN_COUNTING_FROM TIMESTAMP;
BEGIN

select RES_NUM_VALUE
from GET_PARAM('192.168.0.0', 'BILL_CURRENCY_TO_CREDIT', 11)
into :M_COEFF;
select RES_NUM_VALUE
from GET_PARAM('192.168.0.0', 'BILL_CREDIT_TO_CURRENCY', 11)
into :C_COEFF;
if (M_COEFF is null or (0=M_COEFF)) then
   M_COEFF = 1;
if (C_COEFF is null or (0=C_COEFF)) then
   C_COEFF = 1;

TMP_NONRESTRICTED_BALANCE = 0;
TMP_CASHABLE_BALANCE = 0;
TMP_RESTRICTED_BALANCE = 0;
TMP_FICHAS_BALANCE = 0;
TMP_RESERVA_BALANCE = 0;
TMP_BANCO_BALANCE = 0;
TMP_TOTAL_IN = 0;
TMP_TOTAL_OUT = 0;
TMP_TOTAL_BETS = 0;
TMP_TOTAL_WINS = 0;
TMP_TOTAL_RES_BETS = 0;
TMP_TOTAL_NONRES_BETS = 0;
TMP_BILL_IN = 0;
TMP_BILL_OUT = 0;
TMP_STACKER_TOTAL = 0;
TMP_BILLS_IN_STACKER = 0;
TMP_COIN_IN = 0;
TMP_COIN_OUT = 0;
TMP_COINS_TO_CASHBOX = 0;
TMP_COINS_TO_HOPPER = 0;
TMP_COIN_HOPPER_LEVEL = 0;
TMP_ELECTRONIC_IN = 0;
TMP_ELECTRONIC_OUT = 0;
TMP_ELECTRONIC_CASH_IN_CENTS = 0;
TMP_ELECTRONIC_CASH_OUT_CENTS = 0;
TMP_ELECTRONIC_RES_IN_CENTS = 0;
TMP_ELECTRONIC_RES_OUT_CENTS = 0;
TMP_ELECTRONIC_NONRES_IN_CENTS = 0;
TMP_ELECTRONIC_NONRES_OUT_CENTS = 0;
TMP_HANDPAY = 0;
TMP_ADMIN_KEY_IN = 0;
TMP_ADMIN_KEY_OUT = 0;
TMP_BONUS_CASH_IN_CENTS = 0;
TMP_BONUS_NONRES_IN_CENTS = 0;
TMP_BONUS_OUT = 0;
TMP_TICKETS_IN_QTY = 0;
TMP_TICKETS_OUT_QTY = 0;
TMP_TICKET_IN = 0;
TMP_TICKET_OUT = 0;
TMP_TICKET_CASH_IN = 0;
TMP_TICKET_CASH_OUT = 0;
TMP_TICKET_RES_IN = 0;
TMP_TICKET_RES_OUT = 0;
TMP_TICKET_NONRES_IN = 0;
TMP_JACKPOT_WIN = 0;
TMP_JACKPOTS_WON = 0;
TMP_GAMES_PLAYED = 0;
TMP_GAMES_WON = 0;
TMP_GAMES_LOST = 0;
TMP_GAMES_SINCE_POWER_UP = 0;
TMP_GAMES_SINCE_DOOR_CLOSE = 0;
TMP_POWER_UP_COUNT = 0;
TMP_DOOR_CLOSE_COUNT = 0;

TMP_CREDITOS_TOTAL = 0;
TMP_RESERVA_TOTAL = 0;
TMP_BANCO_TOTAL = 0;
TMP_FICHAS_TOTAL = 0;
TMP_RESERVA_TO_CREDITOS = 0;
TMP_BANCO_TO_CREDITOS = 0;
TMP_FICHAS_TO_BANCO = 0;
TMP_RETURN_CHANGE_TOTAL = 0;
TMP_PAYOUT_ROUNDED_TOTAL = 0;
TMP_CYCLES_COMPLETED = 0;
TMP_FG_TOTAL_BET = 0;
TMP_FG_FICHAS_WIN = 0;
TMP_FG_PREMIO_WIN = 0;
TMP_FG_NADA_WIN = 0;
TMP_FG_RES_FICHAS_COUNT = 0;
TMP_FG_RES_PREMIO_COUNT = 0;
TMP_FG_RES_NADA_COUNT = 0;
TMP_FG_RES_MYSTERY_COUNT = 0;
TMP_FG_TOTAL_GAMES = 0;
TMP_FG_20_GAMES = 0;
TMP_FG_40_GAMES = 0;
TMP_FG_50_GAMES = 0;
TMP_FG_60_GAMES = 0;
TMP_FG_80_GAMES = 0;
TMP_FG_100_GAMES = 0;
TMP_FG_200_GAMES = 0;
TMP_FG_300_GAMES = 0;
TMP_FG_600_GAMES = 0;
TMP_MIN_COUNTING_FROM = NULL;

for select case CLIENT_IP
                when '192.168.0.0' then 'Roulette'
                when '192.168.0.1' then 'Player 1'
                when '192.168.0.2' then 'Player 2'
                when '192.168.0.3' then 'Player 3'
                when '192.168.0.4' then 'Player 4'
                when '192.168.0.5' then 'Player 5'
                when '192.168.0.6' then 'Player 6'
                when '192.168.0.7' then 'Player 7'
                when '192.168.0.8' then 'Player 8'
                when '192.168.0.9' then 'Player 9'
                when '192.168.0.10' then 'Player 10'
                when '192.168.0.11' then 'Player 11'
                when '192.168.0.12' then 'Player 12'
                when '192.168.0.13' then 'Player 13'
                when '192.168.0.14' then 'Player 14'
                when '192.168.0.15' then 'Player 15'
                when '192.168.0.16' then 'Player 16'
                when '192.168.0.17' then 'Player 17'
                when '192.168.0.18' then 'Player 18'
                when '192.168.0.19' then 'Player 19'
                when '192.168.0.20' then 'Player 20'
                when '192.168.0.21' then 'Player 21'
                when '192.168.0.22' then 'Player 22'
                when '192.168.0.23' then 'Player 23'
                when '192.168.0.24' then 'Player 24'
                when '192.168.0.25' then 'Player 25'
                when '192.168.0.26' then 'Player 26'
                when '192.168.0.27' then 'Player 27'
                when '192.168.0.28' then 'Player 28'
                when '192.168.0.29' then 'Player 29'
                when '192.168.0.30' then 'Player 30'
                when '192.168.0.31' then 'Player 31'
                when '192.168.0.32' then 'Player 32'
                when '192.168.0.33' then 'Player 33'
                when '192.168.0.34' then 'Player 34'
                when '192.168.0.35' then 'Player 35'
                when '192.168.0.36' then 'Player 36'
                when '192.168.0.37' then 'Player 37'
                when '192.168.0.38' then 'Player 38'
                when '192.168.0.39' then 'Player 39'
                when '192.168.0.40' then 'Player 40'
                when '192.168.0.41' then 'Player 41'
                when '192.168.0.42' then 'Player 42'
                when '192.168.0.43' then 'Player 43'
                when '192.168.0.44' then 'Player 44'
                when '192.168.0.45' then 'Player 45'
                when '192.168.0.46' then 'Player 46'
                when '192.168.0.47' then 'Player 47'
                when '192.168.0.48' then 'Player 48'
                when '192.168.0.49' then 'Player 49'
                when '192.168.0.50' then 'Player 50'
                else CLIENT_IP
                end as DESCRIPTION,
                case CLIENT_IP
                when '192.168.0.0' then 999/*skupno je zadnji*/
                when '192.168.0.1' then 1
                when '192.168.0.2' then 2
                when '192.168.0.3' then 3
                when '192.168.0.4' then 4
                when '192.168.0.5' then 5
                when '192.168.0.6' then 6
                when '192.168.0.7' then 7
                when '192.168.0.8' then 8
                when '192.168.0.9' then 9
                when '192.168.0.10' then 10
                when '192.168.0.11' then 11
                when '192.168.0.12' then 12
                when '192.168.0.13' then 13
                when '192.168.0.14' then 14
                when '192.168.0.15' then 15
                when '192.168.0.16' then 16
                when '192.168.0.17' then 17
                when '192.168.0.18' then 18
                when '192.168.0.19' then 19
                when '192.168.0.20' then 20
                when '192.168.0.21' then 21
                when '192.168.0.22' then 22
                when '192.168.0.23' then 23
                when '192.168.0.24' then 24
                when '192.168.0.25' then 25
                when '192.168.0.26' then 26
                when '192.168.0.27' then 27
                when '192.168.0.28' then 28
                when '192.168.0.29' then 29
                when '192.168.0.30' then 30
                when '192.168.0.31' then 31
                when '192.168.0.32' then 32
                when '192.168.0.33' then 33
                when '192.168.0.34' then 34
                when '192.168.0.35' then 35
                when '192.168.0.36' then 36
                when '192.168.0.37' then 37
                when '192.168.0.38' then 38
                when '192.168.0.39' then 39
                when '192.168.0.40' then 40
                when '192.168.0.41' then 41
                when '192.168.0.42' then 42
                when '192.168.0.43' then 43
                when '192.168.0.44' then 44
                when '192.168.0.45' then 45
                when '192.168.0.46' then 46
                when '192.168.0.47' then 47
                when '192.168.0.48' then 48
                when '192.168.0.49' then 49
                when '192.168.0.50' then 50
                else 51/*po potrebi dodaj - tale STATION NUMBER SE UPORABLJA SAMO ZA SORTIRANJE, ker STRING SE SORTIRA Player 1, Player 10, Player 11, Player 2,...*/
           end as STATION_NUMBER,
           CLIENT_IP
    from DIGITAL_COUNTERS
    where COUNTER_INDEX<1000
    and   COUNTER_INDEX>=0
    group by CLIENT_IP
    order by 2 ascending, CLIENT_IP ASCENDING
    into :RES_CLIENT_CAPTION,
         :RES_TOTAL_IN, --tega ne rabimo, gre v zacasno spremenljivko
         :RES_CLIENT_IP
do begin

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+10)
   into RES_NONRESTRICTED_BALANCE;
   TMP_NONRESTRICTED_BALANCE = TMP_NONRESTRICTED_BALANCE+RES_NONRESTRICTED_BALANCE;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4)),
          RES_COUNTING_FROM
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+11)
   into :RES_CASHABLE_BALANCE,
        :RES_COUNTING_FROM;
   TMP_CASHABLE_BALANCE = TMP_CASHABLE_BALANCE+RES_CASHABLE_BALANCE;
   if (TMP_MIN_COUNTING_FROM is null or RES_COUNTING_FROM<TMP_MIN_COUNTING_FROM ) then
      TMP_MIN_COUNTING_FROM = RES_COUNTING_FROM;--zapomnemo si najmanjsi datum za ALL

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+12)
   into RES_RESTRICTED_BALANCE;
   TMP_RESTRICTED_BALANCE = TMP_RESTRICTED_BALANCE+RES_RESTRICTED_BALANCE;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+13)
   into RES_FICHAS_BALANCE;
   TMP_FICHAS_BALANCE = TMP_FICHAS_BALANCE+RES_FICHAS_BALANCE;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+14)
   into RES_RESERVA_BALANCE;
   TMP_RESERVA_BALANCE = TMP_RESERVA_BALANCE+RES_RESERVA_BALANCE;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+15)
   into RES_BANCO_BALANCE;
   TMP_BANCO_BALANCE = TMP_BANCO_BALANCE+RES_BANCO_BALANCE;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+51)
   into RES_TOTAL_IN;
   TMP_TOTAL_IN = TMP_TOTAL_IN+RES_TOTAL_IN;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+52)
   into RES_TOTAL_OUT;
   TMP_TOTAL_OUT = TMP_TOTAL_OUT+RES_TOTAL_OUT;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+53)
   into RES_TOTAL_BETS;
   TMP_TOTAL_BETS = TMP_TOTAL_BETS+RES_TOTAL_BETS;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+54)
   into RES_TOTAL_WINS;
   TMP_TOTAL_WINS = TMP_TOTAL_WINS+RES_TOTAL_WINS;

       select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
       from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+55)
       into RES_TOTAL_RES_BETS;
       TMP_TOTAL_RES_BETS = TMP_TOTAL_RES_BETS+RES_TOTAL_RES_BETS;

       select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
       from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+56)
       into RES_TOTAL_NONRES_BETS;
       TMP_TOTAL_NONRES_BETS = TMP_TOTAL_NONRES_BETS+RES_TOTAL_NONRES_BETS;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+322)
   into RES_BILL_IN;
   TMP_BILL_IN = TMP_BILL_IN+RES_BILL_IN;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+324)
   into RES_BILL_OUT;
   TMP_BILL_OUT = TMP_BILL_OUT+RES_BILL_OUT;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+321)
   into RES_STACKER_TOTAL;
   TMP_STACKER_TOTAL = TMP_STACKER_TOTAL+RES_STACKER_TOTAL;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+320)
   into RES_BILLS_IN_STACKER;
   TMP_BILLS_IN_STACKER = TMP_BILLS_IN_STACKER+RES_BILLS_IN_STACKER;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+400)
   into RES_COIN_IN;
   TMP_COIN_IN = TMP_COIN_IN+RES_COIN_IN;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+401)
   into RES_COIN_OUT;
   TMP_COIN_OUT = TMP_COIN_OUT+RES_COIN_OUT;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+402)
   into RES_COINS_TO_CASHBOX;
   TMP_COINS_TO_CASHBOX = TMP_COINS_TO_CASHBOX+RES_COINS_TO_CASHBOX;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+403)
   into RES_COINS_TO_HOPPER;
   TMP_COINS_TO_HOPPER = TMP_COINS_TO_HOPPER+RES_COINS_TO_HOPPER;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+404)
   into RES_COIN_HOPPER_LEVEL;
   TMP_COIN_HOPPER_LEVEL = TMP_COIN_HOPPER_LEVEL+RES_COIN_HOPPER_LEVEL;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+500)
   into RES_ELECTRONIC_IN;
   TMP_ELECTRONIC_IN = TMP_ELECTRONIC_IN+RES_ELECTRONIC_IN;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+501)
   into RES_ELECTRONIC_OUT;
   TMP_ELECTRONIC_OUT = TMP_ELECTRONIC_OUT+RES_ELECTRONIC_OUT;

       select (RES_COUNTER_VALUE*1)/cast(100 as numeric(18,4))/*tevec teje v centih*/
       from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+505)
       into RES_ELECTRONIC_CASH_IN_CENTS;
       TMP_ELECTRONIC_CASH_IN_CENTS = TMP_ELECTRONIC_CASH_IN_CENTS+RES_ELECTRONIC_CASH_IN_CENTS;

       select (RES_COUNTER_VALUE*1)/cast(100 as numeric(18,4))/*tevec teje v centih*/
       from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+506)
       into RES_ELECTRONIC_CASH_OUT_CENTS;
       TMP_ELECTRONIC_CASH_OUT_CENTS = TMP_ELECTRONIC_CASH_OUT_CENTS+RES_ELECTRONIC_CASH_OUT_CENTS;

       select (RES_COUNTER_VALUE*1)/cast(100 as numeric(18,4))/*tevec teje v centih*/
       from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+509)
       into RES_ELECTRONIC_RES_IN_CENTS;
       TMP_ELECTRONIC_RES_IN_CENTS = TMP_ELECTRONIC_RES_IN_CENTS+RES_ELECTRONIC_RES_IN_CENTS;

       select (RES_COUNTER_VALUE*1)/cast(100 as numeric(18,4))/*tevec teje v centih*/
       from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+510)
       into RES_ELECTRONIC_RES_OUT_CENTS;
       TMP_ELECTRONIC_RES_OUT_CENTS = TMP_ELECTRONIC_RES_OUT_CENTS+RES_ELECTRONIC_RES_OUT_CENTS;

       select (RES_COUNTER_VALUE*1)/cast(100 as numeric(18,4))/*tevec teje v centih*/
       from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+513)
       into RES_ELECTRONIC_NONRES_IN_CENTS;
       TMP_ELECTRONIC_NONRES_IN_CENTS = TMP_ELECTRONIC_NONRES_IN_CENTS+RES_ELECTRONIC_NONRES_IN_CENTS;

       select (RES_COUNTER_VALUE*1)/cast(100 as numeric(18,4))/*tevec teje v centih*/
       from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+514)
       into RES_ELECTRONIC_NONRES_OUT_CENTS;
       TMP_ELECTRONIC_NONRES_OUT_CENTS = TMP_ELECTRONIC_NONRES_OUT_CENTS+RES_ELECTRONIC_NONRES_OUT_CENTS;

       select RES_COUNTER_VALUE
       from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+600)
       into RES_TICKETS_IN_QTY;
       TMP_TICKETS_IN_QTY = TMP_TICKETS_IN_QTY+RES_TICKETS_IN_QTY;

       select RES_COUNTER_VALUE
       from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+601)
       into RES_TICKETS_OUT_QTY;
       TMP_TICKETS_OUT_QTY = TMP_TICKETS_OUT_QTY+RES_TICKETS_OUT_QTY;

       select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
       from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+609)
       into RES_TICKET_CASH_IN;
       TMP_TICKET_CASH_IN = TMP_TICKET_CASH_IN+RES_TICKET_CASH_IN;

       select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
       from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+610)
       into RES_TICKET_CASH_OUT;
       TMP_TICKET_CASH_OUT = TMP_TICKET_CASH_OUT+RES_TICKET_CASH_OUT;

       select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
       from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+615)
       into RES_TICKET_RES_IN;
       TMP_TICKET_RES_IN = TMP_TICKET_RES_IN+RES_TICKET_RES_IN;

       select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
       from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+616)
       into RES_TICKET_RES_OUT;
       TMP_TICKET_RES_OUT = TMP_TICKET_RES_OUT+RES_TICKET_RES_OUT;

       select (RES_COUNTER_VALUE*1)/cast(100 as numeric(18,4))/*tevec teje v centih*/
       from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+617)
       into RES_TICKET_NONRES_IN;
       TMP_TICKET_NONRES_IN = TMP_TICKET_NONRES_IN+RES_TICKET_NONRES_IN;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+504)
   into RES_HANDPAY;
   TMP_HANDPAY = TMP_HANDPAY+RES_HANDPAY;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+700)
   into RES_ADMIN_KEY_IN;
   TMP_ADMIN_KEY_IN = TMP_ADMIN_KEY_IN+RES_ADMIN_KEY_IN;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+701)
   into RES_ADMIN_KEY_OUT;
   TMP_ADMIN_KEY_OUT = TMP_ADMIN_KEY_OUT+RES_ADMIN_KEY_OUT;

       select (RES_COUNTER_VALUE*1)/cast(100 as numeric(18,4))/*tevec teje v centih*/
       from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+557)
       into RES_BONUS_CASH_IN_CENTS;
       TMP_BONUS_CASH_IN_CENTS = TMP_BONUS_CASH_IN_CENTS+RES_BONUS_CASH_IN_CENTS;

       select (RES_COUNTER_VALUE*1)/cast(100 as numeric(18,4))/*tevec teje v centih*/
       from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+559)
       into RES_BONUS_NONRES_IN_CENTS;
       TMP_BONUS_NONRES_IN_CENTS = TMP_BONUS_NONRES_IN_CENTS+RES_BONUS_NONRES_IN_CENTS;

       select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
       from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+561)
       into RES_BONUS_OUT;
       TMP_BONUS_OUT = TMP_BONUS_OUT+RES_BONUS_OUT;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+602)
   into RES_TICKET_IN;
   TMP_TICKET_IN = TMP_TICKET_IN+RES_TICKET_IN;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+603)
   into RES_TICKET_OUT;
   TMP_TICKET_OUT = TMP_TICKET_OUT+RES_TICKET_OUT;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+517)
   into RES_JACKPOT_WIN;
   TMP_JACKPOT_WIN = TMP_JACKPOT_WIN+RES_JACKPOT_WIN;

   select RES_COUNTER_VALUE/*tevec teje kolikokrat se je jackpot zgodil*/
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+518)
   into RES_JACKPOTS_WON;
   TMP_JACKPOTS_WON = TMP_JACKPOTS_WON+RES_JACKPOTS_WON;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+300)
   into RES_GAMES_PLAYED;
   TMP_GAMES_PLAYED = TMP_GAMES_PLAYED+RES_GAMES_PLAYED;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+301)
   into RES_GAMES_WON;
   TMP_GAMES_WON = TMP_GAMES_WON+RES_GAMES_WON;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+302)
   into RES_GAMES_LOST;
   TMP_GAMES_LOST = TMP_GAMES_LOST+RES_GAMES_LOST;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+303)
   into RES_GAMES_SINCE_POWER_UP;
   TMP_GAMES_SINCE_POWER_UP = TMP_GAMES_SINCE_POWER_UP+RES_GAMES_SINCE_POWER_UP;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+304)
   into RES_GAMES_SINCE_DOOR_CLOSE;
   TMP_GAMES_SINCE_DOOR_CLOSE = TMP_GAMES_SINCE_DOOR_CLOSE+RES_GAMES_SINCE_DOOR_CLOSE;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+305)
   into RES_POWER_UP_COUNT;
   TMP_POWER_UP_COUNT = TMP_POWER_UP_COUNT+RES_POWER_UP_COUNT;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+306)
   into RES_DOOR_CLOSE_COUNT;
   TMP_DOOR_CLOSE_COUNT = TMP_DOOR_CLOSE_COUNT+RES_DOOR_CLOSE_COUNT;

   if ( RES_TOTAL_BETS is not null and RES_TOTAL_BETS <> 0 ) then
      RES_BET_PROFIT_PERCENT = cast(cast((RES_TOTAL_BETS-RES_TOTAL_WINS)*100/RES_TOTAL_BETS as numeric(13,2))as varchar(13)) || ' %';
   else
       RES_BET_PROFIT_PERCENT ='0,00 %';

   if ( RES_TOTAL_IN is not null and RES_TOTAL_IN <> 0 ) then
      RES_PAYIN_PROFIT_PERCENT = cast(cast((RES_TOTAL_IN-RES_TOTAL_OUT)*100/RES_TOTAL_IN as numeric(13,2))as varchar(13)) || ' %';
   else
      RES_PAYIN_PROFIT_PERCENT ='0,00 %';

   if ( RES_TOTAL_IN is not null and RES_TOTAL_IN <> 0 ) then
      RES_PAYBACK_PERCENT = cast(cast(RES_TOTAL_OUT*100/RES_TOTAL_IN as numeric(13,2))as varchar(13)) || ' %';
   else
      RES_PAYBACK_PERCENT ='0,00 %';



   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+800)
   into RES_CREDITOS_TOTAL;
   TMP_CREDITOS_TOTAL = TMP_CREDITOS_TOTAL+RES_CREDITOS_TOTAL;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+801)
   into RES_RESERVA_TOTAL;
   TMP_RESERVA_TOTAL = TMP_RESERVA_TOTAL+RES_RESERVA_TOTAL;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+802)
   into RES_BANCO_TOTAL;
   TMP_BANCO_TOTAL = TMP_BANCO_TOTAL+RES_BANCO_TOTAL;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+805)
   into RES_FICHAS_TOTAL;
   TMP_FICHAS_TOTAL = TMP_FICHAS_TOTAL+RES_FICHAS_TOTAL;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+803)
   into RES_RESERVA_TO_CREDITOS;
   TMP_RESERVA_TO_CREDITOS = TMP_RESERVA_TO_CREDITOS+RES_RESERVA_TO_CREDITOS;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+804)
   into RES_BANCO_TO_CREDITOS;
   TMP_BANCO_TO_CREDITOS = TMP_BANCO_TO_CREDITOS+RES_BANCO_TO_CREDITOS;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+808)
   into RES_FICHAS_TO_BANCO;
   TMP_FICHAS_TO_BANCO = TMP_FICHAS_TO_BANCO+RES_FICHAS_TO_BANCO;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+825)
   into RES_RETURN_CHANGE_TOTAL;
   TMP_RETURN_CHANGE_TOTAL = TMP_RETURN_CHANGE_TOTAL+RES_RETURN_CHANGE_TOTAL;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+826)
   into RES_PAYOUT_ROUNDED_TOTAL;
   TMP_PAYOUT_ROUNDED_TOTAL = TMP_PAYOUT_ROUNDED_TOTAL+RES_PAYOUT_ROUNDED_TOTAL;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+820)
   into RES_CYCLES_COMPLETED;
   TMP_CYCLES_COMPLETED = TMP_CYCLES_COMPLETED+RES_CYCLES_COMPLETED;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+809)
   into RES_FG_TOTAL_BET;
   TMP_FG_TOTAL_BET = TMP_FG_TOTAL_BET+RES_FG_TOTAL_BET;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+805)
   into RES_FG_FICHAS_WIN;
   TMP_FG_FICHAS_WIN = TMP_FG_FICHAS_WIN+RES_FG_FICHAS_WIN;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+806)
   into RES_FG_PREMIO_WIN;
   TMP_FG_PREMIO_WIN = TMP_FG_PREMIO_WIN+RES_FG_PREMIO_WIN;

   select (RES_COUNTER_VALUE*:M_COEFF)/cast(:C_COEFF as numeric(18,4))
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+807)
   into RES_FG_NADA_WIN;
   TMP_FG_NADA_WIN = TMP_FG_NADA_WIN+RES_FG_NADA_WIN;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+821)
   into RES_FG_RES_NADA_COUNT;
   TMP_FG_RES_NADA_COUNT = TMP_FG_RES_NADA_COUNT+RES_FG_RES_NADA_COUNT;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+822)
   into RES_FG_RES_MYSTERY_COUNT;
   TMP_FG_RES_MYSTERY_COUNT = TMP_FG_RES_MYSTERY_COUNT+RES_FG_RES_MYSTERY_COUNT;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+823)
   into RES_FG_RES_PREMIO_COUNT;
   TMP_FG_RES_PREMIO_COUNT = TMP_FG_RES_PREMIO_COUNT+RES_FG_RES_PREMIO_COUNT;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+824)
   into RES_FG_RES_FICHAS_COUNT;
   TMP_FG_RES_FICHAS_COUNT = TMP_FG_RES_FICHAS_COUNT+RES_FG_RES_FICHAS_COUNT;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+810)
   into RES_FG_TOTAL_GAMES;
   TMP_FG_TOTAL_GAMES = TMP_FG_TOTAL_GAMES+RES_FG_TOTAL_GAMES;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+811)
   into RES_FG_20_GAMES;
   TMP_FG_20_GAMES = TMP_FG_20_GAMES+RES_FG_20_GAMES;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+812)
   into RES_FG_40_GAMES;
   TMP_FG_40_GAMES = TMP_FG_40_GAMES+RES_FG_40_GAMES;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+813)
   into RES_FG_50_GAMES;
   TMP_FG_50_GAMES = TMP_FG_50_GAMES+RES_FG_50_GAMES;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+814)
   into RES_FG_60_GAMES;
   TMP_FG_60_GAMES = TMP_FG_60_GAMES+RES_FG_60_GAMES;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+815)
   into RES_FG_80_GAMES;
   TMP_FG_80_GAMES = TMP_FG_80_GAMES+RES_FG_80_GAMES;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+816)
   into RES_FG_100_GAMES;
   TMP_FG_100_GAMES = TMP_FG_100_GAMES+RES_FG_100_GAMES;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+817)
   into RES_FG_200_GAMES;
   TMP_FG_200_GAMES = TMP_FG_200_GAMES+RES_FG_200_GAMES;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+818)
   into RES_FG_300_GAMES;
   TMP_FG_300_GAMES = TMP_FG_300_GAMES+RES_FG_300_GAMES;

   select RES_COUNTER_VALUE
   from GET_DIGITAL_CNT(:RES_CLIENT_IP, :VAR_COUNTER_ID_SHIFT+819)
   into RES_FG_600_GAMES;
   TMP_FG_600_GAMES = TMP_FG_600_GAMES+RES_FG_600_GAMES;

   suspend;
end

RES_CLIENT_IP = '192.168.0.0';
RES_CLIENT_CAPTION = 'All Players';

RES_NONRESTRICTED_BALANCE = TMP_NONRESTRICTED_BALANCE;
RES_CASHABLE_BALANCE = TMP_CASHABLE_BALANCE;
RES_RESTRICTED_BALANCE = TMP_RESTRICTED_BALANCE;
RES_FICHAS_BALANCE = TMP_FICHAS_BALANCE;
RES_RESERVA_BALANCE = TMP_RESERVA_BALANCE;
RES_BANCO_BALANCE = TMP_BANCO_BALANCE;

RES_TOTAL_IN = TMP_TOTAL_IN;
RES_TOTAL_OUT = TMP_TOTAL_OUT;
RES_TOTAL_BETS = TMP_TOTAL_BETS;
RES_TOTAL_WINS = TMP_TOTAL_WINS;
RES_TOTAL_RES_BETS = TMP_TOTAL_RES_BETS;
RES_TOTAL_NONRES_BETS = TMP_TOTAL_NONRES_BETS;
RES_BILL_IN = TMP_BILL_IN;
RES_BILL_OUT = TMP_BILL_OUT;
RES_STACKER_TOTAL = TMP_STACKER_TOTAL;
RES_BILLS_IN_STACKER = TMP_BILLS_IN_STACKER;
RES_COIN_IN = TMP_COIN_IN;
RES_COIN_OUT = TMP_COIN_OUT;
RES_COINS_TO_CASHBOX = TMP_COINS_TO_CASHBOX;
RES_COINS_TO_HOPPER = TMP_COINS_TO_HOPPER;
RES_COIN_HOPPER_LEVEL = TMP_COIN_HOPPER_LEVEL;
RES_ELECTRONIC_IN = TMP_ELECTRONIC_IN;
RES_ELECTRONIC_OUT = TMP_ELECTRONIC_OUT;
RES_ELECTRONIC_CASH_IN_CENTS = TMP_ELECTRONIC_CASH_IN_CENTS;
RES_ELECTRONIC_CASH_OUT_CENTS = TMP_ELECTRONIC_CASH_OUT_CENTS;
RES_ELECTRONIC_RES_IN_CENTS = TMP_ELECTRONIC_RES_IN_CENTS;
RES_ELECTRONIC_RES_OUT_CENTS = TMP_ELECTRONIC_RES_OUT_CENTS;
RES_ELECTRONIC_NONRES_IN_CENTS = TMP_ELECTRONIC_NONRES_IN_CENTS;
RES_ELECTRONIC_NONRES_OUT_CENTS = TMP_ELECTRONIC_NONRES_OUT_CENTS;
RES_HANDPAY = TMP_HANDPAY;
RES_ADMIN_KEY_IN = TMP_ADMIN_KEY_IN;
RES_ADMIN_KEY_OUT = TMP_ADMIN_KEY_OUT;
RES_BONUS_CASH_IN_CENTS = TMP_BONUS_CASH_IN_CENTS;
RES_BONUS_NONRES_IN_CENTS = TMP_BONUS_NONRES_IN_CENTS;
RES_BONUS_OUT = TMP_BONUS_OUT;
RES_TICKETS_IN_QTY = TMP_TICKETS_IN_QTY;
RES_TICKETS_OUT_QTY = TMP_TICKETS_OUT_QTY;
RES_TICKET_IN = TMP_TICKET_IN;
RES_TICKET_OUT = TMP_TICKET_OUT;
RES_TICKET_CASH_IN = TMP_TICKET_CASH_IN;
RES_TICKET_CASH_OUT = TMP_TICKET_CASH_OUT;
RES_TICKET_RES_IN = TMP_TICKET_RES_IN;
RES_TICKET_RES_OUT = TMP_TICKET_RES_OUT;
RES_TICKET_NONRES_IN = TMP_TICKET_NONRES_IN;
RES_JACKPOT_WIN = TMP_JACKPOT_WIN;
RES_JACKPOTS_WON = TMP_JACKPOTS_WON;
RES_GAMES_PLAYED = TMP_GAMES_PLAYED;
RES_GAMES_WON = TMP_GAMES_WON;
RES_GAMES_LOST = TMP_GAMES_LOST;
RES_GAMES_SINCE_POWER_UP = TMP_GAMES_SINCE_POWER_UP;
RES_GAMES_SINCE_DOOR_CLOSE = TMP_GAMES_SINCE_DOOR_CLOSE;
RES_POWER_UP_COUNT = TMP_POWER_UP_COUNT;
RES_DOOR_CLOSE_COUNT = TMP_DOOR_CLOSE_COUNT;

   if ( RES_TOTAL_BETS is not null and RES_TOTAL_BETS <> 0 ) then
      RES_BET_PROFIT_PERCENT = cast(cast((RES_TOTAL_BETS-RES_TOTAL_WINS)*100/RES_TOTAL_BETS as numeric(13,2))as varchar(13)) || ' %';
   else
       RES_BET_PROFIT_PERCENT ='0,00 %';

   if ( RES_TOTAL_IN is not null and RES_TOTAL_IN <> 0 ) then
      RES_PAYIN_PROFIT_PERCENT = cast(cast((RES_TOTAL_IN-RES_TOTAL_OUT)*100/RES_TOTAL_IN as numeric(13,2))as varchar(13)) || ' %';
   else
      RES_PAYIN_PROFIT_PERCENT ='0,00 %';

   if ( RES_TOTAL_IN is not null and RES_TOTAL_IN <> 0 ) then
      RES_PAYBACK_PERCENT = cast(cast(RES_TOTAL_OUT*100/RES_TOTAL_IN as numeric(13,2))as varchar(13)) || ' %';
   else
      RES_PAYBACK_PERCENT ='0,00 %';

RES_CREDITOS_TOTAL = TMP_CREDITOS_TOTAL;
RES_RESERVA_TOTAL = TMP_RESERVA_TOTAL;
RES_BANCO_TOTAL = TMP_BANCO_TOTAL;
RES_FICHAS_TOTAL = TMP_FICHAS_TOTAL;
RES_RESERVA_TO_CREDITOS = TMP_RESERVA_TO_CREDITOS;
RES_BANCO_TO_CREDITOS = TMP_BANCO_TO_CREDITOS;
RES_FICHAS_TO_BANCO = TMP_FICHAS_TO_BANCO;
RES_RETURN_CHANGE_TOTAL = TMP_RETURN_CHANGE_TOTAL;
RES_PAYOUT_ROUNDED_TOTAL = TMP_PAYOUT_ROUNDED_TOTAL;
RES_CYCLES_COMPLETED = TMP_CYCLES_COMPLETED;
RES_FG_TOTAL_BET = TMP_FG_TOTAL_BET;
RES_FG_FICHAS_WIN = TMP_FG_FICHAS_WIN;
RES_FG_PREMIO_WIN = TMP_FG_PREMIO_WIN;
RES_FG_NADA_WIN = TMP_FG_NADA_WIN;
RES_FG_RES_FICHAS_COUNT = TMP_FG_RES_FICHAS_COUNT;
RES_FG_RES_PREMIO_COUNT = TMP_FG_RES_PREMIO_COUNT;
RES_FG_RES_NADA_COUNT = TMP_FG_RES_NADA_COUNT;
RES_FG_RES_MYSTERY_COUNT = TMP_FG_RES_MYSTERY_COUNT;
RES_FG_TOTAL_GAMES = TMP_FG_TOTAL_GAMES;
RES_FG_20_GAMES = TMP_FG_20_GAMES;
RES_FG_40_GAMES = TMP_FG_40_GAMES;
RES_FG_50_GAMES = TMP_FG_50_GAMES;
RES_FG_60_GAMES = TMP_FG_60_GAMES;
RES_FG_80_GAMES = TMP_FG_80_GAMES;
RES_FG_100_GAMES = TMP_FG_100_GAMES;
RES_FG_200_GAMES = TMP_FG_200_GAMES;
RES_FG_300_GAMES = TMP_FG_300_GAMES;
RES_FG_600_GAMES = TMP_FG_600_GAMES;
RES_COUNTING_FROM = TMP_MIN_COUNTING_FROM;


SUSPEND;
END;
^
set term ; ^

UPDATE LANG_MESSAGES
set LANG_MESSAGE='Please press "Continue" button from attendant menu.'
where LANG_MSG_ID = 90;
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (90, 0, 13, 'Molimo pritisnite "Continue" taster iz operator menija.');
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES 
  (90, 0, 23, 'Por favor, pulse el boton "Continue" del menu del operador.');


UPDATE LANG_MESSAGES
set LANG_MESSAGE='Game stop(61).Cylinder can not find ball'
where LANG_MSG_ID = 61;
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (61, 0, 15, 'Gioco sospeso(61). Il cilindro non trova la pallina.');
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (61, 0, 23, 'Juego se detuvo (61). El cilindro no puede encontrar la bola.');
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (61, 0, 25, 'Game stop(61). Cylinder nemôže nájsť guličku.');


UPDATE LANG_MESSAGES
set LANG_MESSAGE='Game stop(65). Two balls in cylinder.'
where LANG_MSG_ID = 65;
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (65, 0, 15, 'Gioco sospeso(65). Due palle nel cilindro.');
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (65, 0, 23, 'Juego se detuvo(65). Dos bolas en el cilindro.');
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (65, 0, 25, 'Game stop(65). V cylindri sú 2 guličky.');


UPDATE LANG_MESSAGES
set LANG_MESSAGE='Game stop(66). Can not read win number.'
where LANG_MSG_ID = 66;
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (66, 0, 15, 'Gioco sospeso(66). Non si puo leggere il numero vincente.');
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (66, 0, 23, 'Juego se detuvo(66). No puede leer el numero ganador.');
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (66, 0, 25, 'Game stop(66). Nie je možné rozpoznať výherné číslo.');


UPDATE LANG_MESSAGES
set LANG_MESSAGE='Game stop(67). Same win number was read to many times.'
where LANG_MSG_ID = 67;
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (67, 0, 15, 'Gioco sospeso(67). Stesso numero vincente e stato letto troppe volte.');
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (67, 0, 23, 'Juego se detuvo(67). El mismo numero ganador fue leido varias veces.');
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (67, 0, 25, 'Game stop(67). Rovnaké výherné číslo bolo načítané viac krát.');


UPDATE LANG_MESSAGES
set LANG_MESSAGE='Game stop(68). Number Check failed. Call atendant.'
where LANG_MSG_ID = 68;
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (68, 0, 23, 'Juego se detuvo(68). Comprobacion del numbero fracaso. Llama al soporte.');
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (68, 0, 25, 'Game stop(68). Skontrolujte chybu. Privolajte obsluhu.');


UPDATE LANG_MESSAGES
set LANG_MESSAGE='Game Stop(70). Licence has expired.'
where LANG_MSG_ID = 70;
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (70, 0, 15, 'Gioco sospeso(70). Licenza scaduta.');
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (70, 0, 23, 'Juego se detuvo(70). La licencia del software ha expirado.');
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (70, 0, 25, 'Game stop(70). Licencia pre softvér vypršala.');


UPDATE LANG_MESSAGES
set LANG_MESSAGE='Game stop(71). Comunnication error.'
where LANG_MSG_ID = 71;
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (71, 0, 15, 'Gioco sospeso(71). Errore di communicazione.');
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (71, 0, 23, 'Juego se detuvo(71). Error de comunicacion.');
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (71, 0, 25, 'Game stop(71). Chyba komunikácie.');


UPDATE LANG_MESSAGES
set LANG_MESSAGE='Game stop(81). Door is open.'
where LANG_MSG_ID = 81;
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (81, 0, 15, 'Gioco sospeso(81). La porta e aperta.');
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (81, 0, 23, 'Juego se detuvo(81). La puerta esta abierta.');
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (81, 0, 25, 'Game stop(81). Dvere sú otvorené.');


UPDATE LANG_MESSAGES
set LANG_MESSAGE='Game stop(84). Ball was found in eject after blow.'
where LANG_MSG_ID = 84;
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (84, 0, 23, 'Juego se detuvo(84).  La bola fue encrontrada y expulsada despues del soplido.');
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (84, 0, 25, 'Game stop(84). Gulička bola posunutá pri vystrelení.');


UPDATE LANG_MESSAGES
set LANG_MESSAGE='Game stop(85). Ball found in cylinder after drum raise.'
where LANG_MSG_ID = 85;
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (85, 0, 25, 'Game stop(85). Gulička nájdená v cylindri.');


UPDATE LANG_MESSAGES
set LANG_MESSAGE='Game stop(86). Ball was found on the wheel and circumference.'
where LANG_MSG_ID = 86;
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (86, 0, 23, 'Juego se detuvo(86). La bola fue encontrada en la rueda y la circunferencia.');
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (86, 0, 25, 'Game stop(86). Gulička bola nájdená na kolese alebo obvode kolesa rulety.');


UPDATE LANG_MESSAGES
set LANG_MESSAGE='Game stop(87). Two balls on wheel.'
where LANG_MSG_ID = 87;
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (87, 0, 23, 'Juego se detuvo(87). Dos bolas en la rueda.');
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (87, 0, 25, 'Game stop(87). Dve guličky na kolese.');


UPDATE LANG_MESSAGES
set LANG_MESSAGE='Game stop(88). There is no ball detected in cylinder.'
where LANG_MSG_ID = 88;
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (88, 0, 23, 'Juego se detuvo(88). Bola no es detectada en el cilindro.');
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (88, 0, 25, 'Game stop(88). Systém nezaznamenal guličku v cylindri.');


UPDATE LANG_MESSAGES
set LANG_MESSAGE='Game stop(89). Wheel speed abnormaly changed.'
where LANG_MSG_ID = 89;
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (89, 0, 23, 'Juego se detuvo(89). La velocidad de la rueda cambio anormalmente.');
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (89, 0, 25, 'Game stop(89). Rýchlosť kolesa sa zmenila nezvyčajne.');


UPDATE LANG_MESSAGES
set LANG_MESSAGE='Game suspended.'
where LANG_MSG_ID = 780;
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (780, 0, 15, 'Il gioco e sospeso.');
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (780, 0, 23, 'Juego suspendido.');
UPDATE or INSERT INTO LANG_MESSAGES (LANG_MSG_ID, LANG_MSG_SUB_ID, LANG_ID, LANG_MESSAGE)
VALUES
  (780, 0, 25, 'Game suspended.');



commit work;

